get_independent_relevant_phenotypes_server: Identify independent relevant phenotypes (Server Version)

View source: R/independent_phenotype_identification_server.R

get_independent_relevant_phenotypes_serverR Documentation

Identify independent relevant phenotypes (Server Version)

Description

It uses a network clustering process to identify most representative phenotypes when several similar phenotypes are relevant.

Usage

get_independent_relevant_phenotypes_server(
  output_folder,
  channel_file,
  sample_file,
  input_significant_phenotypes = "significant_phenotypes.csv",
  output_file = "independent_phenotypes.csv",
  log_file = "independent_phenotypes.log",
  n_phenotypes = 1000,
  min_confidence = 0.5,
  max_pval = NULL,
  n_threads = 1,
  verbose = FALSE
)

Arguments

output_folder

Path to folder where output files from this and previous steps should be saved.

channel_file

Path to a ".csv" file containing columns named: Channel, Marker, T1, [T2, T3, ... , Tn], [OOB].

sample_file

Path to a ".csv" file containing a Sample_ID column and additional grouping columns for the samples.

n_phenotypes

maximum number of phenotypes to be considered from phen_data filtered by lowest p-values. Default: 1000.

min_confidence

Minimal confidence threshold to filter output. Default: 0.5. #' @param parent_phen Parent phenotype to filter for. All phenotypes in the output will contain the parent phenotype.

max_pval

Maximum p-value. Used to filter phenotypes in final output.

n_threads

Number of threads to be used. Default: 1.

verbose

If TRUE, print outputs from log to stdout.

parent_phen

Parent phenotype to filter for. All phenotypes in the output will contain the parent phenotype.

Details

This server version is just a convenience to find correct inputs and outputs results to file. No performance difference.

Parameters groups_column, g1, g2, max_pval, and parent_phen should match the parameter used in statistically_relevant_phenotypes_server in order to find correct input files.

Value

Output is saved to file.


SciOmicsLab/PhenoComb documentation built on Aug. 26, 2023, 1:28 p.m.